/* BdfServer_Commands - Copyright (c) 2020-2022 Vincent Calame - Exemole
 * Logiciel libre donné sous triple licence :
 * 1) selon les termes de la CeCILL V2
 * 2) selon les termes de l’EUPL V.1.1
 * 3) selon les termes de la GNU GPLv3
 * Voir le fichier licences.txt
 */


package fr.exemole.bdfserver.commands.sphere;

import fr.exemole.bdfserver.api.BdfServer;
import fr.exemole.bdfserver.api.BdfServerEditor;
import fr.exemole.bdfserver.api.namespaces.BdfUserSpace;
import fr.exemole.bdfserver.api.users.BdfUserPrefs;
import fr.exemole.bdfserver.tools.instruction.AbstractBdfCommand;
import fr.exemole.bdfserver.tools.users.BdfUserUtils;
import net.fichotheque.sphere.Redacteur;
import net.mapeadores.util.attr.Attribute;
import net.mapeadores.util.attr.AttributeBuilder;
import net.mapeadores.util.attr.AttributeKey;
import net.mapeadores.util.logging.ErrorMessageException;
import net.mapeadores.util.request.RequestMap;


/**
 *
 * @author Vincent Calame
 */
public class RedacteurCustomizeUICommand extends AbstractBdfCommand {

    public final static String COMMANDNAME = "RedacteurCustomizeUI";
    public final static String COMMANDKEY = "_ USR-06";
    public final static String NOTAB_PARAMNAME = "notab";
    public final static String HIDEEMPTY_PARAMNAME = "hideempty";
    public final static String SYNTAXACTIVE_PARAMNAME = "syntaxactive";
    private BdfUserPrefs redacBdfUserPrefs;
    private boolean noTab;
    private boolean hideEmpty;
    private boolean syntaxActive;

    public RedacteurCustomizeUICommand(BdfServer bdfServer, RequestMap requestMap) {
        super(bdfServer, requestMap);
    }

    @Override
    public boolean needSynchronisation() {
        return true;
    }

    @Override
    protected void doCommand() throws ErrorMessageException {
        BdfServerEditor bdfServerEditor = bdfServer.getBdfServerEditor();
        save(bdfServerEditor, noTab, BdfUserSpace.NOTAB_KEY);
        save(bdfServerEditor, hideEmpty, BdfUserSpace.HIDEEMPTY_KEY);
        save(bdfServerEditor, syntaxActive, BdfUserSpace.SYNTAXACTIVE_KEY);
        bdfServerEditor.saveChanges();
        setDone("_ done.sphere.redacteurcustomizeui");
    }

    @Override
    protected void checkParameters() throws ErrorMessageException {
        Redacteur redacteur = getMandatoryRedacteur();
        boolean isSame = BdfUserUtils.isSame(bdfUser, redacteur);
        if (!isSame) {
            checkSubsetAdmin(redacteur.getSphere());
        }
        if (isSame) {
            redacBdfUserPrefs = bdfUser.getPrefs();
        } else {
            redacBdfUserPrefs = bdfServer.createBdfUser(redacteur).getPrefs();
        }
        this.noTab = requestMap.isTrue(NOTAB_PARAMNAME);
        this.hideEmpty = requestMap.isTrue(HIDEEMPTY_PARAMNAME);
        this.syntaxActive = requestMap.isTrue(SYNTAXACTIVE_PARAMNAME);
    }

    private void save(BdfServerEditor bdfServerEditor, boolean value, AttributeKey attributeKey) {
        if (value) {
            Attribute attribute = AttributeBuilder.toAttribute(attributeKey, "1");
            bdfServerEditor.putAttribute(redacBdfUserPrefs, attribute);
        } else {
            bdfServerEditor.removeAttribute(redacBdfUserPrefs, attributeKey);
        }
    }

}
